# -*- coding: utf-8 -*-
from setupdevhelpers import *


def update_package():
    # Declaring local variables
    package_updated = False
    proxies = get_proxies()
    if not proxies:
        proxies = get_proxies_from_wapt_console()

    url = "https://www.citrix.com/fr-fr/downloads/workspace-app/workspace-app-for-windows-long-term-service-release/workspace-app-for-windows-LTSR-Latest.htm"
    # get latest version version
    dirty_versions = wgets(url, proxies=proxies).split("Version: ")
    # remove first elemet of dirty_versions
    dirty_versions.pop(0)
    clean_versions = []
    # clean versions to isolate the latest version
    for version in dirty_versions:
        clean_versions.append(Version(version.split("(")[0].split("<")[0].strip()))
    # check the highest version in clean_versions

    version = max(clean_versions).versionstring
    versionstrip = ".".join([str(int(u)) for u in version.split(".")])
    latest_bin = "CitrixWorkspaceApp%s.exe" % versionstrip

    # remove_outdated_binaries
    for f in glob.glob("*.exe"):
        if Version(get_file_properties(f)["FileVersion"]) < Version(version):
            print("Delete %s" % f)
            remove_file(f)

    if not isfile(latest_bin):
        wget("https://downloadplugins.citrix.com/ReceiverUpdates/Prod/Receiver/Win/CitrixWorkspaceApp%s.exe" % versionstrip, latest_bin)

    # Checking version from file
    if get_os_name() == "Windows" and "windows" in control.target_os.lower():
        version_from_file = get_version_from_binary(latest_bin, "FileVersion")
        if Version(version_from_file, 4) == Version(version, 4):
            print(f"INFO: Binary file version ({version_from_file}) corresponds to online version ({version})")
        else:
            error(f"ERROR: Binary file version ({version_from_file}) do NOT corresponds to online version ({version})")

    # Changing version of the package
    if Version(version, 4) > Version(control.get_software_version(), 4):
        print("Software version updated (from: %s to: %s)" % (control.get_software_version(), Version(version)))
        package_updated = True
    else:
        print("Software version up-to-date (%s)" % Version(version))
    control.set_software_version(version)
    control.save_control_to_wapt()

    # Validating or not update-package-sources
    return package_updated
